@@ -344,8 +344,6 @@ int main( int argc, char *argv[] )
 	int                     dump=0;
 	int                     time_offset=0, time_delta=0;
 
-	u_64			ratio;
-	
 	kidpid = 0;
 	infile = NULL;
 	opterr = 0;
@@ -468,7 +466,6 @@ int main( int argc, char *argv[] )
 		}
 	}
 	
-	ratio = 0LL;
 	if (stop_jiffies)
 	{/* fkt_record could write the stop time, good */
 		printf("\n");
